@@ -1,4 +1,5 @@
 from django.utils.deprecation import MiddlewareMixin
+from django.conf import settings
 from sso_server.services.token_service import TokenService
 
 
@@ -13,7 +14,7 @@ class UserCookieMiddleWare(MiddlewareMixin):
 			token = TokenService(request)
 			tokens = token.token(grant_type='authorization_code')
 			
-			response.set_cookie('access', tokens.get('access_token'))
-			response.set_cookie('refresh', tokens.get('refresh_token'))
+			response.set_cookie('access', tokens.get('access_token'), domain=settings.DOMAIN)
+			response.set_cookie('refresh', tokens.get('refresh_token'), domain=settings.DOMAIN)
 		
 		return response
