@@ -1,8 +1,8 @@
 from rest_framework.response import Response
 from rest_framework.status import HTTP_200_OK, HTTP_400_BAD_REQUEST
 from rest_framework.views import APIView
-from sso_server.services.token_service import TokenService
 from sso_server.services.get_student_info import GetStudentInfo
+from sso_server.services.token_service import TokenService
 
 
 # Create your views here.
@@ -13,7 +13,8 @@ class UserDataView(APIView):
 	
 	def get(self, request):
 		"""
-		accept access_token in POST request and return user's data in json format
+		Получение базовых данных о пользователе
+		В заголовке запроса нужно передать HTTP_AUTHORIZATION Bearer {access_token}
 		"""
 		result = TokenService.get_user_info_by_token(request.META.get('HTTP_AUTHORIZATION'))
 		return Response(result, status=HTTP_200_OK)
@@ -22,6 +23,8 @@ class UserDataView(APIView):
 class GetStudentInfoView(APIView):
 	"""
 	получение данных студента
+	
+	HTTP_200_OK
 	"""
 	
 	def post(self, request):
@@ -38,8 +41,10 @@ class TokenView(APIView):
 	
 	def post(self, request):
 		"""
+		Получение пары access/refresh токенов.
+		Используется для обновления access по истечению срока годности токена по refresh.
+		
 		В теле запроса необходимо передать дополнительные параметры:
-
 		grant_type=authorization_code/refresh_token
 
 		В ответе вернётся JSON:
@@ -48,6 +53,9 @@ class TokenView(APIView):
 			"token_type": "bearer",
 			"refresh_token": "{refresh_token}"
 		}
+		
+		HTTP_200_OK - успех
+		HTTP_400_BAD_REQUEST - некорректные параметры
 		"""
 		token = TokenService(request)
 		
